import type { NextApiRequest, NextApiResponse } from 'next'

import { spotifyApi } from 'services'
import { Recommendation } from 'types'

export default async function handler(
  req: NextApiRequest,
  res: NextApiResponse
) {
  try {
    const token = req.headers.authorization as string
    spotifyApi.setAccessToken(token)

    const data = req.body as Array<Recommendation>

    const createdPlaylist = await spotifyApi.createPlaylist('randomfy', {
      description:
        'playlist generated by randomfy. Url: https://random-fy.vercel.app/'
    })

    const tracksId = data.map((item) => item.track.uri)

    const addedItems = await spotifyApi.addTracksToPlaylist(
      createdPlaylist.body.id,
      tracksId
    )

    const result = {
      id: createdPlaylist.body.id,
      name: createdPlaylist.body.name,
      uri: createdPlaylist.body.uri,
      description: createdPlaylist.body.description,
      snapshot: addedItems.body
    }

    res.status(200).json(result)
  } catch (error: any) {
    res.status(error?.statusCode || 400).json(error)
  }
}
